@@ -7,7 +7,7 @@ use Mojo::URL;
 
 use Getopt::Long qw(GetOptionsFromArray);
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 has description => 'Quick reference tool for the reddit API';
 
@@ -29,7 +29,7 @@ EOF
 
 has ua => sub { Mojo::UserAgent->new() };
 
-has url => 'http://www.reddit.com/dev/api';
+has url => 'https://www.reddit.com/dev/api';
 
 sub _print_all_endpoints {
     my $self = shift;
@@ -55,11 +55,16 @@ sub _print_all_endpoints {
 }
 
 sub _pretty_print {
-    my ($self, $scopes, $desc, $params) = @_;
+    my ($self, $title, $scopes, $desc, $params) = @_;
+
+    my $divider = join '', "=" x length $title;
+
+    say "$divider\n$title\n$divider\n";
 
     say "OAuth Scopes:\n\n$scopes\n";
 
-    say "Description:\n\n$desc\n";
+    print "Description:";
+    say length $desc ? "\n\n$desc\n" : " n/a\n";
 
     say "Parameters:\n\n$params";
 }
@@ -68,9 +73,17 @@ sub _get_info {
     my ($self, $container) = @_;
 
     my $scopes = $container->find('.api-badge\ oauth-scope')->map(    #
-        sub { ' * ' . $_->text } # indentaion
+        sub {
+            # indentaion
+            my $t = ' * ' . $_->text;
+            # Remove scope element so not to appear in $title text.
+            $_->remove();
+            $t;
+        }
     )->join("\n\n");
 
+    my $title = $container->at('h3')->all_text;
+
     my $desc = $container->find('.md p')->map(
         sub {
             unless ($_->text =~ /\bSee also\b/) {
@@ -112,7 +125,7 @@ sub _get_info {
         }
     )->join("\n\n");
 
-    $self->_pretty_print($scopes, $desc, $params);
+    $self->_pretty_print($title, $scopes, $desc, $params);
 }
 
 sub run {
@@ -140,9 +153,16 @@ sub run {
     $endpoint =~ s@^/@@;     # remove leading /
     $endpoint =~ s@/@_@g;    # look like URL fragment
 
-    my $container = $self->ua->get($self->url)->res->dom->at('div[id$=' . $endpoint . ']');
+    my @containers = $self->ua->get($self->url)->res->dom->find('div[id*=' . $endpoint . ']')->each(
+        sub {
+            $self->_get_info($_);
+        }
+    );
 
-    $self->_get_info($container);
+    unless (@containers) {
+        print "No endpoint matching that text was found.\n";
+        return;
+    }
 }
 
 1;
